---
title: '[릴리즈노트] 2024-06-19 업데이트'
category: 업데이트
tags:
  - API / SDK
  - 업데이트
searchTags:
  - 이니시스 보안
  - 웹훅 시크릿
  - 웹훅 기능
  - V2 웹훅
  - 웹훅 신버전
  - 토스페이 연동
  - 'V2 직연동 '
  - 릴리즈노트
  - 업데이트
datetime: 2024-06-18T15:00:00.000Z
---

<Callout title="2024년 6월 19일 API / SDK 업데이트 소식을 안내드립니다." />



## **주요 업데이트 사항**

<Tag text="결제 서비스 V2" />

✔️ 포트원 V2 결제모듈에서 토스페이 결제 직연동을 지원합니다.

이제 포트원 V2를 통해 토스페이 직연동이 가능합니다. 이번 업데이트를 통해 일반결제 및 정기결제를 지원합니다.

토스페이에서 지원하는 결제수단은 아래와 같습니다.

- 카드
- 계좌
- 토스머니

토스페이 연동에 대해 자세히 알고 싶다면 [→ 토스페이 연동가이드](https://developers.portone.io/opi/ko/integration/pg/v2/tosspay-v2?v=v2)에서 확인하실 수 있습니다.

<Tag text="결제 서비스 V2" />

✔️ 웹훅 신버전이 추가되었습니다.

V2 결제모듈을 이용하시는 경우 빌링키 발급 관련 웹훅을 받아보실 수 있습니다.

웹훅을 연동하여 이벤트 발생 시 결제 건의 상태를 동기화할 수 있습니다.

웹훅 버전에 대한 자세한 내용은 [웹훅 연동하기](https://developers.portone.io/opi/ko/integration/webhook/readme-v2?v=v2)에서 확인하실 수 있습니다.

<Tag text="결제 서비스 V2" />

✔️ 웹훅 시크릿 기능이 추가되었습니다.

V2 결제모듈을 이용하시는 경우 웹훅 시크릿을 사용하여 포트원이 생성한 웹훅 요청인지 출처를 확인할 수 있으며, 악의적인 공격자가 보낸 웹훅 요청을 차단할 수 있습니다.

웹훅 시크릿에 대한 자세한 내용은 [웹훅 연동하기](https://developers.portone.io/opi/ko/integration/webhook/readme-v2?v=v2)에서 확인하실 수 있습니다.

## 기타 업데이트 사항

<Tag text="결제 서비스 V1" />

✔️ 이니시스 통합인증 시 보안성이 강화되었습니다.

이제 포트원을 통한 이니시스 통합인증 이용시 민감정보를 암호화하여 처리할 수 있습니다.

고객사에서는 별도로 추가 대응 없이 바로 적용되어 사용하실 수 있습니다.

##### [\[API / SDK 릴리즈노트\] 2024-06-19 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-06-19)
